leaftools.Leaf
==============

.. abjad-lineage:: abjad.tools.leaftools.Leaf.Leaf.Leaf

.. autoclass:: abjad.tools.leaftools.Leaf.Leaf.Leaf

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.lilypond_duration_multiplier
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.lilypond_format
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.override
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.select
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.set
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.storage_format
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.written_duration
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_at_sounding_pitch
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_nonsemantic
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.__copy__
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.__eq__
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.__mul__
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.__ne__
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.__repr__
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.__rmul__
      ~abjad.tools.leaftools.Leaf.Leaf.Leaf.__str__

Bases
-----

- :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.override
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.set
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.lilypond_duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_duration
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_nonsemantic
   :noindex:

Methods
-------

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.select
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__copy__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__eq__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__mul__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__ne__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__repr__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__rmul__
   :noindex:

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__str__
   :noindex:
